@@ -1,12 +1,14 @@
 #' Construct canonical names
 #'
+#' This function is depreciated. Please use \link{make_canonical}
+#'
 #' Canonical names using Genus, Species and Subspecies friends
 #'
 #' @param dat data frame containing taxonomic list
 #' @param genus field name for Genus field
 #' @param species field name for Species field
 #' @param subspecies field name for Subspecies field
-#' @family name functions
+#' @family Discontinued functions
 #' @return a data frame containing Canonical names field added or repopulated using
 #'     filed names for Genus, Species and Subspecies specified in parameters
 #' @examples
@@ -15,6 +17,7 @@
 #' }
 #' @export
 MakeCanonical <- function(dat,genus="",species="",subspecies=""){
+  .Deprecated("cast_cs_field")
   newdat <- as.data.frame(dat)
   newdat$canonical <- ""
   if(genus==""){
