@@ -1,19 +1,22 @@
 #' match two taxonomic lists
 #'
+#' This function is depreciated. Please use \link{match_lists}
+#'
 #' match two taxonomic lists using canonical names
 #'
 #' @param master master taxonomic list
 #' @param lst match  taxonomic list
 #' @param masterfld field name for canonical name in master list
 #' @param lstfld field name for canonical name in match list
-#' @family list functions
+#' @family Discontinued functions
 #' @return a list with two data frames containing matched and non-matched names from the master list
 #' @examples
 #' \dontrun{
-#' MakeCanonical(master,lst,"canonical","canonical",)
+#' MatchLists(master,lst,"canonical","canonical")
 #' }
 #' @export
 MatchLists <- function(master,lst,masterfld,lstfld){
+  .Deprecated("match_lists")
   retval <- NULL
   if(masterfld==""){
     return(NULL)
